
# Type: has molecular consequence


connects a sequence variant to a class describing the molecular consequence. E.g.  SO:0001583

URI: [biolink:has_molecular_consequence](https://w3id.org/biolink/vocab/has_molecular_consequence)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>0..*</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
